==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AutoHealTriggersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Triggers for auto-heal.
 * @property privateBytesInKB A rule based on private bytes.
 * @property requests A rule based on total requests.
 * @property slowRequests A rule based on request execution time.
 * @property slowRequestsWithPath A rule based on multiple Slow Requests Rule with path
 * @property statusCodes A rule based on status codes.
 * @property statusCodesRange A rule based on status codes ranges.
 */
public data class AutoHealTriggersArgs(
    public val privateBytesInKB: Output<Int>? = null,
    public val requests: Output<RequestsBasedTriggerArgs>? = null,
    public val slowRequests: Output<SlowRequestsBasedTriggerArgs>? = null,
    public val slowRequestsWithPath: Output<List<SlowRequestsBasedTriggerArgs>>? = null,
    public val statusCodes: Output<List<StatusCodesBasedTriggerArgs>>? = null,
    public val statusCodesRange: Output<List<StatusCodesRangeBasedTriggerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs =
        com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs.builder()
            .privateBytesInKB(privateBytesInKB?.applyValue({ args0 -> args0 }))
            .requests(requests?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .slowRequests(slowRequests?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .slowRequestsWithPath(
                slowRequestsWithPath?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .statusCodes(
                statusCodes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .statusCodesRange(
                statusCodesRange?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoHealTriggersArgs].
 */
@PulumiTagMarker
public class AutoHealTriggersArgsBuilder internal constructor() {
    private var privateBytesInKB: Output<Int>? = null

    private var requests: Output<RequestsBasedTriggerArgs>? = null

    private var slowRequests: Output<SlowRequestsBasedTriggerArgs>? = null

    private var slowRequestsWithPath: Output<List<SlowRequestsBasedTriggerArgs>>? = null

    private var statusCodes: Output<List<StatusCodesBasedTriggerArgs>>? = null

    private var statusCodesRange: Output<List<StatusCodesRangeBasedTriggerArgs>>? = null

    /**
     * @param value A rule based on private bytes.
     */
    @JvmName("eajhqgwpfjgcvjdg")
    public suspend fun privateBytesInKB(`value`: Output<Int>) {
        this.privateBytesInKB = value
    }

    /**
     * @param value A rule based on total requests.
     */
    @JvmName("uettwowyinfqxxsi")
    public suspend fun requests(`value`: Output<RequestsBasedTriggerArgs>) {
        this.requests = value
    }

    /**
     * @param value A rule based on request execution time.
     */
    @JvmName("ibxhkoywxmnccgig")
    public suspend fun slowRequests(`value`: Output<SlowRequestsBasedTriggerArgs>) {
        this.slowRequests = value
    }

    /**
     * @param value A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("vjkqbiroyjnjiumf")
    public suspend fun slowRequestsWithPath(`value`: Output<List<SlowRequestsBasedTriggerArgs>>) {
        this.slowRequestsWithPath = value
    }

    @JvmName("pdlkhfcnytrwuofe")
    public suspend fun slowRequestsWithPath(vararg values: Output<SlowRequestsBasedTriggerArgs>) {
        this.slowRequestsWithPath = Output.all(values.asList())
    }

    /**
     * @param values A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("mngnjemflypiwfbd")
    public suspend fun slowRequestsWithPath(values: List<Output<SlowRequestsBasedTriggerArgs>>) {
        this.slowRequestsWithPath = Output.all(values)
    }

    /**
     * @param value A rule based on status codes.
     */
    @JvmName("bbnwdqocdqwrgbww")
    public suspend fun statusCodes(`value`: Output<List<StatusCodesBasedTriggerArgs>>) {
        this.statusCodes = value
    }

    @JvmName("phrquyqjvootyoay")
    public suspend fun statusCodes(vararg values: Output<StatusCodesBasedTriggerArgs>) {
        this.statusCodes = Output.all(values.asList())
    }

    /**
     * @param values A rule based on status codes.
     */
    @JvmName("sfgfkyssygubttdr")
    public suspend fun statusCodes(values: List<Output<StatusCodesBasedTriggerArgs>>) {
        this.statusCodes = Output.all(values)
    }

    /**
     * @param value A rule based on status codes ranges.
     */
    @JvmName("rvuxiqedhumawmtw")
    public suspend fun statusCodesRange(`value`: Output<List<StatusCodesRangeBasedTriggerArgs>>) {
        this.statusCodesRange = value
    }

    @JvmName("bldloqeaaridkxha")
    public suspend fun statusCodesRange(vararg values: Output<StatusCodesRangeBasedTriggerArgs>) {
        this.statusCodesRange = Output.all(values.asList())
    }

    /**
     * @param values A rule based on status codes ranges.
     */
    @JvmName("fgtjnfatondmgpjk")
    public suspend fun statusCodesRange(values: List<Output<StatusCodesRangeBasedTriggerArgs>>) {
        this.statusCodesRange = Output.all(values)
    }

    /**
     * @param value A rule based on private bytes.
     */
    @JvmName("ijstfdlkyqdhvprb")
    public suspend fun privateBytesInKB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateBytesInKB = mapped
    }

    /**
     * @param value A rule based on total requests.
     */
    @JvmName("qsltvbvrjaalvmbm")
    public suspend fun requests(`value`: RequestsBasedTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requests = mapped
    }

    /**
     * @param argument A rule based on total requests.
     */
    @JvmName("ouojpokvsciwmcxy")
    public suspend fun requests(argument: suspend RequestsBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = RequestsBasedTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.requests = mapped
    }

    /**
     * @param value A rule based on request execution time.
     */
    @JvmName("uabiaccdlsjrskye")
    public suspend fun slowRequests(`value`: SlowRequestsBasedTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slowRequests = mapped
    }

    /**
     * @param argument A rule based on request execution time.
     */
    @JvmName("akoxrnxfwkfaiwfu")
    public suspend
    fun slowRequests(argument: suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = SlowRequestsBasedTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.slowRequests = mapped
    }

    /**
     * @param value A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("kdoxstqridjwgaqt")
    public suspend fun slowRequestsWithPath(`value`: List<SlowRequestsBasedTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param argument A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("yqujfenlwikisvrg")
    public suspend
    fun slowRequestsWithPath(argument: List<suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SlowRequestsBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param argument A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("nkowlmdfjxhfbxwv")
    public suspend fun slowRequestsWithPath(
        vararg
        argument: suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SlowRequestsBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param argument A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("ekeexnvfbrgpjoxu")
    public suspend
    fun slowRequestsWithPath(argument: suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SlowRequestsBasedTriggerArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param values A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("owssntdipujvwxqg")
    public suspend fun slowRequestsWithPath(vararg values: SlowRequestsBasedTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param value A rule based on status codes.
     */
    @JvmName("hqhtkjddrermeesx")
    public suspend fun statusCodes(`value`: List<StatusCodesBasedTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statusCodes = mapped
    }

    /**
     * @param argument A rule based on status codes.
     */
    @JvmName("jtfthcghjxmpipsd")
    public suspend
    fun statusCodes(argument: List<suspend StatusCodesBasedTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StatusCodesBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodes = mapped
    }

    /**
     * @param argument A rule based on status codes.
     */
    @JvmName("wjtukrxuqsmjuwuq")
    public suspend fun statusCodes(
        vararg
        argument: suspend StatusCodesBasedTriggerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StatusCodesBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodes = mapped
    }

    /**
     * @param argument A rule based on status codes.
     */
    @JvmName("eiwyreaclnmcycjs")
    public suspend fun statusCodes(argument: suspend StatusCodesBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StatusCodesBasedTriggerArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.statusCodes = mapped
    }

    /**
     * @param values A rule based on status codes.
     */
    @JvmName("wyjqpvimqcbkgqer")
    public suspend fun statusCodes(vararg values: StatusCodesBasedTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statusCodes = mapped
    }

    /**
     * @param value A rule based on status codes ranges.
     */
    @JvmName("sxcgbrjoayvfvagb")
    public suspend fun statusCodesRange(`value`: List<StatusCodesRangeBasedTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statusCodesRange = mapped
    }

    /**
     * @param argument A rule based on status codes ranges.
     */
    @JvmName("lbjrahdiaosehxns")
    public suspend
    fun statusCodesRange(argument: List<suspend StatusCodesRangeBasedTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StatusCodesRangeBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodesRange = mapped
    }

    /**
     * @param argument A rule based on status codes ranges.
     */
    @JvmName("bxvbpvwtdidnmohw")
    public suspend fun statusCodesRange(
        vararg
        argument: suspend StatusCodesRangeBasedTriggerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StatusCodesRangeBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodesRange = mapped
    }

    /**
     * @param argument A rule based on status codes ranges.
     */
    @JvmName("alaplywbdwocgakd")
    public suspend
    fun statusCodesRange(argument: suspend StatusCodesRangeBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StatusCodesRangeBasedTriggerArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.statusCodesRange = mapped
    }

    /**
     * @param values A rule based on status codes ranges.
     */
    @JvmName("vufkirhqwyohrxky")
    public suspend fun statusCodesRange(vararg values: StatusCodesRangeBasedTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statusCodesRange = mapped
    }

    internal fun build(): AutoHealTriggersArgs = AutoHealTriggersArgs(
        privateBytesInKB = privateBytesInKB,
        requests = requests,
        slowRequests = slowRequests,
        slowRequestsWithPath = slowRequestsWithPath,
        statusCodes = statusCodes,
        statusCodesRange = statusCodesRange,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AutoHealTriggersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Triggers for auto-heal.
 * @property privateBytesInKB A rule based on private bytes.
 * @property requests A rule based on total requests.
 * @property slowRequests A rule based on request execution time.
 * @property slowRequestsWithPath A rule based on multiple Slow Requests Rule with path
 * @property statusCodes A rule based on status codes.
 * @property statusCodesRange A rule based on status codes ranges.
 */
public data class AutoHealTriggersArgs(
    public val privateBytesInKB: Output<Int>? = null,
    public val requests: Output<RequestsBasedTriggerArgs>? = null,
    public val slowRequests: Output<SlowRequestsBasedTriggerArgs>? = null,
    public val slowRequestsWithPath: Output<List<SlowRequestsBasedTriggerArgs>>? = null,
    public val statusCodes: Output<List<StatusCodesBasedTriggerArgs>>? = null,
    public val statusCodesRange: Output<List<StatusCodesRangeBasedTriggerArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs =
        com.pulumi.azurenative.web.inputs.AutoHealTriggersArgs.builder()
            .privateBytesInKB(privateBytesInKB?.applyValue({ args0 -> args0 }))
            .requests(requests?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .slowRequests(slowRequests?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .slowRequestsWithPath(
                slowRequestsWithPath?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .statusCodes(
                statusCodes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .statusCodesRange(
                statusCodesRange?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoHealTriggersArgs].
 */
@PulumiTagMarker
public class AutoHealTriggersArgsBuilder internal constructor() {
    private var privateBytesInKB: Output<Int>? = null

    private var requests: Output<RequestsBasedTriggerArgs>? = null

    private var slowRequests: Output<SlowRequestsBasedTriggerArgs>? = null

    private var slowRequestsWithPath: Output<List<SlowRequestsBasedTriggerArgs>>? = null

    private var statusCodes: Output<List<StatusCodesBasedTriggerArgs>>? = null

    private var statusCodesRange: Output<List<StatusCodesRangeBasedTriggerArgs>>? = null

    /**
     * @param value A rule based on private bytes.
     */
    @JvmName("yulxriudqqbcqlgw")
    public suspend fun privateBytesInKB(`value`: Output<Int>) {
        this.privateBytesInKB = value
    }

    /**
     * @param value A rule based on total requests.
     */
    @JvmName("mxaexinqxesilqqa")
    public suspend fun requests(`value`: Output<RequestsBasedTriggerArgs>) {
        this.requests = value
    }

    /**
     * @param value A rule based on request execution time.
     */
    @JvmName("sjeeivpbeyoeqbbf")
    public suspend fun slowRequests(`value`: Output<SlowRequestsBasedTriggerArgs>) {
        this.slowRequests = value
    }

    /**
     * @param value A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("epcjoyejgchvgrki")
    public suspend fun slowRequestsWithPath(`value`: Output<List<SlowRequestsBasedTriggerArgs>>) {
        this.slowRequestsWithPath = value
    }

    @JvmName("wgtwdoksycvrqegv")
    public suspend fun slowRequestsWithPath(vararg values: Output<SlowRequestsBasedTriggerArgs>) {
        this.slowRequestsWithPath = Output.all(values.asList())
    }

    /**
     * @param values A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("bqwrrnrqifgxvxhg")
    public suspend fun slowRequestsWithPath(values: List<Output<SlowRequestsBasedTriggerArgs>>) {
        this.slowRequestsWithPath = Output.all(values)
    }

    /**
     * @param value A rule based on status codes.
     */
    @JvmName("dkxunbpsdxjipxhd")
    public suspend fun statusCodes(`value`: Output<List<StatusCodesBasedTriggerArgs>>) {
        this.statusCodes = value
    }

    @JvmName("xjnfwwpdxnikweft")
    public suspend fun statusCodes(vararg values: Output<StatusCodesBasedTriggerArgs>) {
        this.statusCodes = Output.all(values.asList())
    }

    /**
     * @param values A rule based on status codes.
     */
    @JvmName("eiovaewqmwxyygbh")
    public suspend fun statusCodes(values: List<Output<StatusCodesBasedTriggerArgs>>) {
        this.statusCodes = Output.all(values)
    }

    /**
     * @param value A rule based on status codes ranges.
     */
    @JvmName("wtikakwsstefgvuo")
    public suspend fun statusCodesRange(`value`: Output<List<StatusCodesRangeBasedTriggerArgs>>) {
        this.statusCodesRange = value
    }

    @JvmName("mdyxvbskofflabkw")
    public suspend fun statusCodesRange(vararg values: Output<StatusCodesRangeBasedTriggerArgs>) {
        this.statusCodesRange = Output.all(values.asList())
    }

    /**
     * @param values A rule based on status codes ranges.
     */
    @JvmName("uywvvcglbvebimum")
    public suspend fun statusCodesRange(values: List<Output<StatusCodesRangeBasedTriggerArgs>>) {
        this.statusCodesRange = Output.all(values)
    }

    /**
     * @param value A rule based on private bytes.
     */
    @JvmName("honekenyysexjdha")
    public suspend fun privateBytesInKB(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateBytesInKB = mapped
    }

    /**
     * @param value A rule based on total requests.
     */
    @JvmName("twckuuspfgdrapah")
    public suspend fun requests(`value`: RequestsBasedTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requests = mapped
    }

    /**
     * @param argument A rule based on total requests.
     */
    @JvmName("upmcnyblqoenubmv")
    public suspend fun requests(argument: suspend RequestsBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = RequestsBasedTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.requests = mapped
    }

    /**
     * @param value A rule based on request execution time.
     */
    @JvmName("vkgjcwjgyvepmqdc")
    public suspend fun slowRequests(`value`: SlowRequestsBasedTriggerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slowRequests = mapped
    }

    /**
     * @param argument A rule based on request execution time.
     */
    @JvmName("civcpouwdisaydyw")
    public suspend
    fun slowRequests(argument: suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = SlowRequestsBasedTriggerArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.slowRequests = mapped
    }

    /**
     * @param value A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("dlsbisxckvwupnwk")
    public suspend fun slowRequestsWithPath(`value`: List<SlowRequestsBasedTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param argument A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("sofhvsqhtdpbciui")
    public suspend
    fun slowRequestsWithPath(argument: List<suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SlowRequestsBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param argument A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("laqjdfbldvaxubbc")
    public suspend fun slowRequestsWithPath(
        vararg
        argument: suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SlowRequestsBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param argument A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("qqagfwysumptkigf")
    public suspend
    fun slowRequestsWithPath(argument: suspend SlowRequestsBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SlowRequestsBasedTriggerArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param values A rule based on multiple Slow Requests Rule with path
     */
    @JvmName("hbwqbjoesphowmtt")
    public suspend fun slowRequestsWithPath(vararg values: SlowRequestsBasedTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.slowRequestsWithPath = mapped
    }

    /**
     * @param value A rule based on status codes.
     */
    @JvmName("nehhesswgnvvyoxu")
    public suspend fun statusCodes(`value`: List<StatusCodesBasedTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statusCodes = mapped
    }

    /**
     * @param argument A rule based on status codes.
     */
    @JvmName("aaqqheaftquwhydm")
    public suspend
    fun statusCodes(argument: List<suspend StatusCodesBasedTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StatusCodesBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodes = mapped
    }

    /**
     * @param argument A rule based on status codes.
     */
    @JvmName("xoaamsgsjwkymoaf")
    public suspend fun statusCodes(
        vararg
        argument: suspend StatusCodesBasedTriggerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StatusCodesBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodes = mapped
    }

    /**
     * @param argument A rule based on status codes.
     */
    @JvmName("frhlytmvhrbcpruw")
    public suspend fun statusCodes(argument: suspend StatusCodesBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StatusCodesBasedTriggerArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.statusCodes = mapped
    }

    /**
     * @param values A rule based on status codes.
     */
    @JvmName("megrpndyjyrymdrv")
    public suspend fun statusCodes(vararg values: StatusCodesBasedTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statusCodes = mapped
    }

    /**
     * @param value A rule based on status codes ranges.
     */
    @JvmName("vlnjxrhxapxotmqb")
    public suspend fun statusCodesRange(`value`: List<StatusCodesRangeBasedTriggerArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.statusCodesRange = mapped
    }

    /**
     * @param argument A rule based on status codes ranges.
     */
    @JvmName("meyqvlpivhrawftw")
    public suspend
    fun statusCodesRange(argument: List<suspend StatusCodesRangeBasedTriggerArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            StatusCodesRangeBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodesRange = mapped
    }

    /**
     * @param argument A rule based on status codes ranges.
     */
    @JvmName("rcdgipsuetixnifm")
    public suspend fun statusCodesRange(
        vararg
        argument: suspend StatusCodesRangeBasedTriggerArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            StatusCodesRangeBasedTriggerArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statusCodesRange = mapped
    }

    /**
     * @param argument A rule based on status codes ranges.
     */
    @JvmName("ucwptrrfdutstfbo")
    public suspend
    fun statusCodesRange(argument: suspend StatusCodesRangeBasedTriggerArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            StatusCodesRangeBasedTriggerArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.statusCodesRange = mapped
    }

    /**
     * @param values A rule based on status codes ranges.
     */
    @JvmName("fivahuiwpixcdwsj")
    public suspend fun statusCodesRange(vararg values: StatusCodesRangeBasedTriggerArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statusCodesRange = mapped
    }

    internal fun build(): AutoHealTriggersArgs = AutoHealTriggersArgs(
        privateBytesInKB = privateBytesInKB,
        requests = requests,
        slowRequests = slowRequests,
        slowRequestsWithPath = slowRequestsWithPath,
        statusCodes = statusCodes,
        statusCodesRange = statusCodesRange,
    )
}
